package Data::Object::Func::Any;

use Data::Object 'Class';

extends 'Data::Object::Func';

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::Func::Any

=cut

=head1 ABSTRACT

Functions for Any Data

=cut

=head1 SYNOPSIS

  use Data::Object::Func::Any;

=cut

=head1 DESCRIPTION

Data::Object::Func::Any is an abstract base class for function classes in the
Data::Object::Func::Any space.

=cut
